This function subsets gt_clumppling objects to a set of individuals or a set of values of K. This is intended to create plot insets, or to visualise a subset of individuals during data analysis. To understand the modes within a subset of individuals in your data, you should subset your gt_admix object and re-run gt_clumppling.

subset_gt_clumppling(x, k = NULL, indivs = NULL)

Arguments

x

a gt_clumppling object

k

a vector of k values to subset to

indivs

a vector of individual indices to keep

Value

a gt_clumppling object subsetted to the individuals specified